@@ -35,7 +35,7 @@ def _recur_fib(n):
    if n <= 1:  
        return n  
    else:  
-       return(_recur_fibo(n-1) + _recur_fibo(n-2))
+       return(_recur_fib(n-1) + _recur_fib(n-2))
 
 def get_fib(terms):
 	if terms <= 0:
